@@ -11,7 +11,7 @@
 #include <kdev-pg-list.h>
 
 
-# 58 "/build/kdevelop-php/src/kdev-php-5.5.2/parser/php.g" 1
+# 58 "/build/kdevelop-php/src/kdev-php-5.6.2/parser/php.g" 1
 
 
 #include <QtCore/QRegularExpression>
@@ -26,7 +26,7 @@ namespace Php
 {
 
 
-# 92 "/build/kdevelop-php/src/kdev-php-5.5.2/parser/php.g" 1
+# 92 "/build/kdevelop-php/src/kdev-php-5.6.2/parser/php.g" 1
 
 class Lexer;
 
@@ -228,7 +228,7 @@ struct KDEVPHPPARSER_EXPORT AstNode
     qint64 startToken;
     qint64 endToken;
 
-# 147 "/build/kdevelop-php/src/kdev-php-5.5.2/parser/php.g" 1
+# 147 "/build/kdevelop-php/src/kdev-php-5.6.2/parser/php.g" 1
 
     KDevelop::DUContext* ducontext;
 
@@ -378,7 +378,7 @@ struct KDEVPHPPARSER_EXPORT CatchItemAst: public AstNode
 {
     enum { KIND = CatchItemKind };
 
-    NamespacedIdentifierAst *catchClass;
+    const KDevPG::ListNode<NamespacedIdentifierAst *> *catchClassSequence;
     VariableIdentifierAst *var;
     InnerStatementListAst *statements;
 };
